/*******************************************************************************
* File Name: EchoTimer.c
* Version 2.0
*
* Description:
*  This file provides the source code to the API for the EchoTimer
*  component
*
* Note:
*  None
*
********************************************************************************
* Copyright 2013-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "EchoTimer.h"

uint8 EchoTimer_initVar = 0u;


/*******************************************************************************
* Function Name: EchoTimer_Init
********************************************************************************
*
* Summary:
*  Initialize/Restore default EchoTimer configuration.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void EchoTimer_Init(void)
{

    /* Set values from customizer to CTRL */
    #if (EchoTimer__QUAD == EchoTimer_CONFIG)
        EchoTimer_CONTROL_REG = EchoTimer_CTRL_QUAD_BASE_CONFIG;
        
        /* Set values from customizer to CTRL1 */
        EchoTimer_TRIG_CONTROL1_REG  = EchoTimer_QUAD_SIGNALS_MODES;

        /* Set values from customizer to INTR */
        EchoTimer_SetInterruptMode(EchoTimer_QUAD_INTERRUPT_MASK);
        
         /* Set other values */
        EchoTimer_SetCounterMode(EchoTimer_COUNT_DOWN);
        EchoTimer_WritePeriod(EchoTimer_QUAD_PERIOD_INIT_VALUE);
        EchoTimer_WriteCounter(EchoTimer_QUAD_PERIOD_INIT_VALUE);
    #endif  /* (EchoTimer__QUAD == EchoTimer_CONFIG) */

    #if (EchoTimer__TIMER == EchoTimer_CONFIG)
        EchoTimer_CONTROL_REG = EchoTimer_CTRL_TIMER_BASE_CONFIG;
        
        /* Set values from customizer to CTRL1 */
        EchoTimer_TRIG_CONTROL1_REG  = EchoTimer_TIMER_SIGNALS_MODES;
    
        /* Set values from customizer to INTR */
        EchoTimer_SetInterruptMode(EchoTimer_TC_INTERRUPT_MASK);
        
        /* Set other values from customizer */
        EchoTimer_WritePeriod(EchoTimer_TC_PERIOD_VALUE );

        #if (EchoTimer__COMPARE == EchoTimer_TC_COMP_CAP_MODE)
            EchoTimer_WriteCompare(EchoTimer_TC_COMPARE_VALUE);

            #if (1u == EchoTimer_TC_COMPARE_SWAP)
                EchoTimer_SetCompareSwap(1u);
                EchoTimer_WriteCompareBuf(EchoTimer_TC_COMPARE_BUF_VALUE);
            #endif  /* (1u == EchoTimer_TC_COMPARE_SWAP) */
        #endif  /* (EchoTimer__COMPARE == EchoTimer_TC_COMP_CAP_MODE) */

        /* Initialize counter value */
        #if (EchoTimer_CY_TCPWM_V2 && EchoTimer_TIMER_UPDOWN_CNT_USED && !EchoTimer_CY_TCPWM_4000)
            EchoTimer_WriteCounter(1u);
        #elif(EchoTimer__COUNT_DOWN == EchoTimer_TC_COUNTER_MODE)
            EchoTimer_WriteCounter(EchoTimer_TC_PERIOD_VALUE);
        #else
            EchoTimer_WriteCounter(0u);
        #endif /* (EchoTimer_CY_TCPWM_V2 && EchoTimer_TIMER_UPDOWN_CNT_USED && !EchoTimer_CY_TCPWM_4000) */
    #endif  /* (EchoTimer__TIMER == EchoTimer_CONFIG) */

    #if (EchoTimer__PWM_SEL == EchoTimer_CONFIG)
        EchoTimer_CONTROL_REG = EchoTimer_CTRL_PWM_BASE_CONFIG;

        #if (EchoTimer__PWM_PR == EchoTimer_PWM_MODE)
            EchoTimer_CONTROL_REG |= EchoTimer_CTRL_PWM_RUN_MODE;
            EchoTimer_WriteCounter(EchoTimer_PWM_PR_INIT_VALUE);
        #else
            EchoTimer_CONTROL_REG |= EchoTimer_CTRL_PWM_ALIGN | EchoTimer_CTRL_PWM_KILL_EVENT;
            
            /* Initialize counter value */
            #if (EchoTimer_CY_TCPWM_V2 && EchoTimer_PWM_UPDOWN_CNT_USED && !EchoTimer_CY_TCPWM_4000)
                EchoTimer_WriteCounter(1u);
            #elif (EchoTimer__RIGHT == EchoTimer_PWM_ALIGN)
                EchoTimer_WriteCounter(EchoTimer_PWM_PERIOD_VALUE);
            #else 
                EchoTimer_WriteCounter(0u);
            #endif  /* (EchoTimer_CY_TCPWM_V2 && EchoTimer_PWM_UPDOWN_CNT_USED && !EchoTimer_CY_TCPWM_4000) */
        #endif  /* (EchoTimer__PWM_PR == EchoTimer_PWM_MODE) */

        #if (EchoTimer__PWM_DT == EchoTimer_PWM_MODE)
            EchoTimer_CONTROL_REG |= EchoTimer_CTRL_PWM_DEAD_TIME_CYCLE;
        #endif  /* (EchoTimer__PWM_DT == EchoTimer_PWM_MODE) */

        #if (EchoTimer__PWM == EchoTimer_PWM_MODE)
            EchoTimer_CONTROL_REG |= EchoTimer_CTRL_PWM_PRESCALER;
        #endif  /* (EchoTimer__PWM == EchoTimer_PWM_MODE) */

        /* Set values from customizer to CTRL1 */
        EchoTimer_TRIG_CONTROL1_REG  = EchoTimer_PWM_SIGNALS_MODES;
    
        /* Set values from customizer to INTR */
        EchoTimer_SetInterruptMode(EchoTimer_PWM_INTERRUPT_MASK);

        /* Set values from customizer to CTRL2 */
        #if (EchoTimer__PWM_PR == EchoTimer_PWM_MODE)
            EchoTimer_TRIG_CONTROL2_REG =
                    (EchoTimer_CC_MATCH_NO_CHANGE    |
                    EchoTimer_OVERLOW_NO_CHANGE      |
                    EchoTimer_UNDERFLOW_NO_CHANGE);
        #else
            #if (EchoTimer__LEFT == EchoTimer_PWM_ALIGN)
                EchoTimer_TRIG_CONTROL2_REG = EchoTimer_PWM_MODE_LEFT;
            #endif  /* ( EchoTimer_PWM_LEFT == EchoTimer_PWM_ALIGN) */

            #if (EchoTimer__RIGHT == EchoTimer_PWM_ALIGN)
                EchoTimer_TRIG_CONTROL2_REG = EchoTimer_PWM_MODE_RIGHT;
            #endif  /* ( EchoTimer_PWM_RIGHT == EchoTimer_PWM_ALIGN) */

            #if (EchoTimer__CENTER == EchoTimer_PWM_ALIGN)
                EchoTimer_TRIG_CONTROL2_REG = EchoTimer_PWM_MODE_CENTER;
            #endif  /* ( EchoTimer_PWM_CENTER == EchoTimer_PWM_ALIGN) */

            #if (EchoTimer__ASYMMETRIC == EchoTimer_PWM_ALIGN)
                EchoTimer_TRIG_CONTROL2_REG = EchoTimer_PWM_MODE_ASYM;
            #endif  /* (EchoTimer__ASYMMETRIC == EchoTimer_PWM_ALIGN) */
        #endif  /* (EchoTimer__PWM_PR == EchoTimer_PWM_MODE) */

        /* Set other values from customizer */
        EchoTimer_WritePeriod(EchoTimer_PWM_PERIOD_VALUE );
        EchoTimer_WriteCompare(EchoTimer_PWM_COMPARE_VALUE);

        #if (1u == EchoTimer_PWM_COMPARE_SWAP)
            EchoTimer_SetCompareSwap(1u);
            EchoTimer_WriteCompareBuf(EchoTimer_PWM_COMPARE_BUF_VALUE);
        #endif  /* (1u == EchoTimer_PWM_COMPARE_SWAP) */

        #if (1u == EchoTimer_PWM_PERIOD_SWAP)
            EchoTimer_SetPeriodSwap(1u);
            EchoTimer_WritePeriodBuf(EchoTimer_PWM_PERIOD_BUF_VALUE);
        #endif  /* (1u == EchoTimer_PWM_PERIOD_SWAP) */
    #endif  /* (EchoTimer__PWM_SEL == EchoTimer_CONFIG) */
    
}


/*******************************************************************************
* Function Name: EchoTimer_Enable
********************************************************************************
*
* Summary:
*  Enables the EchoTimer.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void EchoTimer_Enable(void)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();
    EchoTimer_BLOCK_CONTROL_REG |= EchoTimer_MASK;
    CyExitCriticalSection(enableInterrupts);

    /* Start Timer or PWM if start input is absent */
    #if (EchoTimer__PWM_SEL == EchoTimer_CONFIG)
        #if (0u == EchoTimer_PWM_START_SIGNAL_PRESENT)
            EchoTimer_TriggerCommand(EchoTimer_MASK, EchoTimer_CMD_START);
        #endif /* (0u == EchoTimer_PWM_START_SIGNAL_PRESENT) */
    #endif /* (EchoTimer__PWM_SEL == EchoTimer_CONFIG) */

    #if (EchoTimer__TIMER == EchoTimer_CONFIG)
        #if (0u == EchoTimer_TC_START_SIGNAL_PRESENT)
            EchoTimer_TriggerCommand(EchoTimer_MASK, EchoTimer_CMD_START);
        #endif /* (0u == EchoTimer_TC_START_SIGNAL_PRESENT) */
    #endif /* (EchoTimer__TIMER == EchoTimer_CONFIG) */
}


/*******************************************************************************
* Function Name: EchoTimer_Start
********************************************************************************
*
* Summary:
*  Initializes the EchoTimer with default customizer
*  values when called the first time and enables the EchoTimer.
*  For subsequent calls the configuration is left unchanged and the component is
*  just enabled.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  EchoTimer_initVar: global variable is used to indicate initial
*  configuration of this component.  The variable is initialized to zero and set
*  to 1 the first time EchoTimer_Start() is called. This allows
*  enabling/disabling a component without re-initialization in all subsequent
*  calls to the EchoTimer_Start() routine.
*
*******************************************************************************/
void EchoTimer_Start(void)
{
    if (0u == EchoTimer_initVar)
    {
        EchoTimer_Init();
        EchoTimer_initVar = 1u;
    }

    EchoTimer_Enable();
}


/*******************************************************************************
* Function Name: EchoTimer_Stop
********************************************************************************
*
* Summary:
*  Disables the EchoTimer.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void EchoTimer_Stop(void)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    EchoTimer_BLOCK_CONTROL_REG &= (uint32)~EchoTimer_MASK;

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: EchoTimer_SetMode
********************************************************************************
*
* Summary:
*  Sets the operation mode of the EchoTimer. This function is used when
*  configured as a generic EchoTimer and the actual mode of operation is
*  set at runtime. The mode must be set while the component is disabled.
*
* Parameters:
*  mode: Mode for the EchoTimer to operate in
*   Values:
*   - EchoTimer_MODE_TIMER_COMPARE - Timer / Counter with
*                                                 compare capability
*         - EchoTimer_MODE_TIMER_CAPTURE - Timer / Counter with
*                                                 capture capability
*         - EchoTimer_MODE_QUAD - Quadrature decoder
*         - EchoTimer_MODE_PWM - PWM
*         - EchoTimer_MODE_PWM_DT - PWM with dead time
*         - EchoTimer_MODE_PWM_PR - PWM with pseudo random capability
*
* Return:
*  None
*
*******************************************************************************/
void EchoTimer_SetMode(uint32 mode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    EchoTimer_CONTROL_REG &= (uint32)~EchoTimer_MODE_MASK;
    EchoTimer_CONTROL_REG |= mode;

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: EchoTimer_SetQDMode
********************************************************************************
*
* Summary:
*  Sets the the Quadrature Decoder to one of the 3 supported modes.
*  Its functionality is only applicable to Quadrature Decoder operation.
*
* Parameters:
*  qdMode: Quadrature Decoder mode
*   Values:
*         - EchoTimer_MODE_X1 - Counts on phi 1 rising
*         - EchoTimer_MODE_X2 - Counts on both edges of phi1 (2x faster)
*         - EchoTimer_MODE_X4 - Counts on both edges of phi1 and phi2
*                                        (4x faster)
*
* Return:
*  None
*
*******************************************************************************/
void EchoTimer_SetQDMode(uint32 qdMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    EchoTimer_CONTROL_REG &= (uint32)~EchoTimer_QUAD_MODE_MASK;
    EchoTimer_CONTROL_REG |= qdMode;

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: EchoTimer_SetPrescaler
********************************************************************************
*
* Summary:
*  Sets the prescaler value that is applied to the clock input.  Not applicable
*  to a PWM with the dead time mode or Quadrature Decoder mode.
*
* Parameters:
*  prescaler: Prescaler divider value
*   Values:
*         - EchoTimer_PRESCALE_DIVBY1    - Divide by 1 (no prescaling)
*         - EchoTimer_PRESCALE_DIVBY2    - Divide by 2
*         - EchoTimer_PRESCALE_DIVBY4    - Divide by 4
*         - EchoTimer_PRESCALE_DIVBY8    - Divide by 8
*         - EchoTimer_PRESCALE_DIVBY16   - Divide by 16
*         - EchoTimer_PRESCALE_DIVBY32   - Divide by 32
*         - EchoTimer_PRESCALE_DIVBY64   - Divide by 64
*         - EchoTimer_PRESCALE_DIVBY128  - Divide by 128
*
* Return:
*  None
*
*******************************************************************************/
void EchoTimer_SetPrescaler(uint32 prescaler)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    EchoTimer_CONTROL_REG &= (uint32)~EchoTimer_PRESCALER_MASK;
    EchoTimer_CONTROL_REG |= prescaler;

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: EchoTimer_SetOneShot
********************************************************************************
*
* Summary:
*  Writes the register that controls whether the EchoTimer runs
*  continuously or stops when terminal count is reached.  By default the
*  EchoTimer operates in the continuous mode.
*
* Parameters:
*  oneShotEnable
*   Values:
*     - 0 - Continuous
*     - 1 - Enable One Shot
*
* Return:
*  None
*
*******************************************************************************/
void EchoTimer_SetOneShot(uint32 oneShotEnable)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    EchoTimer_CONTROL_REG &= (uint32)~EchoTimer_ONESHOT_MASK;
    EchoTimer_CONTROL_REG |= ((uint32)((oneShotEnable & EchoTimer_1BIT_MASK) <<
                                                               EchoTimer_ONESHOT_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: EchoTimer_SetPWMMode
********************************************************************************
*
* Summary:
*  Writes the control register that determines what mode of operation the PWM
*  output lines are driven in.  There is a setting for what to do on a
*  comparison match (CC_MATCH), on an overflow (OVERFLOW) and on an underflow
*  (UNDERFLOW).  The value for each of the three must be ORed together to form
*  the mode.
*
* Parameters:
*  modeMask: A combination of three mode settings.  Mask must include a value
*  for each of the three or use one of the preconfigured PWM settings.
*   Values:
*     - CC_MATCH_SET        - Set on comparison match
*     - CC_MATCH_CLEAR      - Clear on comparison match
*     - CC_MATCH_INVERT     - Invert on comparison match
*     - CC_MATCH_NO_CHANGE  - No change on comparison match
*     - OVERLOW_SET         - Set on overflow
*     - OVERLOW_CLEAR       - Clear on  overflow
*     - OVERLOW_INVERT      - Invert on overflow
*     - OVERLOW_NO_CHANGE   - No change on overflow
*     - UNDERFLOW_SET       - Set on underflow
*     - UNDERFLOW_CLEAR     - Clear on underflow
*     - UNDERFLOW_INVERT    - Invert on underflow
*     - UNDERFLOW_NO_CHANGE - No change on underflow
*     - PWM_MODE_LEFT       - Setting for left aligned PWM.  Should be combined
*                             with up counting mode
*     - PWM_MODE_RIGHT      - Setting for right aligned PWM.  Should be combined
*                             with down counting mode
*     - PWM_MODE_CENTER     - Setting for center aligned PWM.  Should be
*                             combined with up/down 0 mode
*     - PWM_MODE_ASYM       - Setting for asymmetric PWM.  Should be combined
*                             with up/down 1 mode
*
* Return:
*  None
*
*******************************************************************************/
void EchoTimer_SetPWMMode(uint32 modeMask)
{
    EchoTimer_TRIG_CONTROL2_REG = (modeMask & EchoTimer_6BIT_MASK);
}



/*******************************************************************************
* Function Name: EchoTimer_SetPWMSyncKill
********************************************************************************
*
* Summary:
*  Writes the register that controls whether the PWM kill signal (stop input)
*  causes asynchronous or synchronous kill operation.  By default the kill
*  operation is asynchronous.  This functionality is only applicable to the PWM
*  and PWM with dead time modes.
*
*  For Synchronous mode the kill signal disables both the line and line_n
*  signals until the next terminal count.
*
*  For Asynchronous mode the kill signal disables both the line and line_n
*  signals when the kill signal is present.  This mode should only be used
*  when the kill signal (stop input) is configured in the pass through mode
*  (Level sensitive signal).

*
* Parameters:
*  syncKillEnable
*   Values:
*     - 0 - Asynchronous
*     - 1 - Synchronous
*
* Return:
*  None
*
*******************************************************************************/
void EchoTimer_SetPWMSyncKill(uint32 syncKillEnable)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    EchoTimer_CONTROL_REG &= (uint32)~EchoTimer_PWM_SYNC_KILL_MASK;
    EchoTimer_CONTROL_REG |= ((uint32)((syncKillEnable & EchoTimer_1BIT_MASK)  <<
                                               EchoTimer_PWM_SYNC_KILL_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: EchoTimer_SetPWMStopOnKill
********************************************************************************
*
* Summary:
*  Writes the register that controls whether the PWM kill signal (stop input)
*  causes the PWM counter to stop.  By default the kill operation does not stop
*  the counter.  This functionality is only applicable to the three PWM modes.
*
*
* Parameters:
*  stopOnKillEnable
*   Values:
*     - 0 - Don't stop
*     - 1 - Stop
*
* Return:
*  None
*
*******************************************************************************/
void EchoTimer_SetPWMStopOnKill(uint32 stopOnKillEnable)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    EchoTimer_CONTROL_REG &= (uint32)~EchoTimer_PWM_STOP_KILL_MASK;
    EchoTimer_CONTROL_REG |= ((uint32)((stopOnKillEnable & EchoTimer_1BIT_MASK)  <<
                                                         EchoTimer_PWM_STOP_KILL_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: EchoTimer_SetPWMDeadTime
********************************************************************************
*
* Summary:
*  Writes the dead time control value.  This value delays the rising edge of
*  both the line and line_n signals the designated number of cycles resulting
*  in both signals being inactive for that many cycles.  This functionality is
*  only applicable to the PWM in the dead time mode.

*
* Parameters:
*  Dead time to insert
*   Values: 0 to 255
*
* Return:
*  None
*
*******************************************************************************/
void EchoTimer_SetPWMDeadTime(uint32 deadTime)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    EchoTimer_CONTROL_REG &= (uint32)~EchoTimer_PRESCALER_MASK;
    EchoTimer_CONTROL_REG |= ((uint32)((deadTime & EchoTimer_8BIT_MASK) <<
                                                          EchoTimer_PRESCALER_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: EchoTimer_SetPWMInvert
********************************************************************************
*
* Summary:
*  Writes the bits that control whether the line and line_n outputs are
*  inverted from their normal output values.  This functionality is only
*  applicable to the three PWM modes.
*
* Parameters:
*  mask: Mask of outputs to invert.
*   Values:
*         - EchoTimer_INVERT_LINE   - Inverts the line output
*         - EchoTimer_INVERT_LINE_N - Inverts the line_n output
*
* Return:
*  None
*
*******************************************************************************/
void EchoTimer_SetPWMInvert(uint32 mask)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    EchoTimer_CONTROL_REG &= (uint32)~EchoTimer_INV_OUT_MASK;
    EchoTimer_CONTROL_REG |= mask;

    CyExitCriticalSection(enableInterrupts);
}



/*******************************************************************************
* Function Name: EchoTimer_WriteCounter
********************************************************************************
*
* Summary:
*  Writes a new 16bit counter value directly into the counter register, thus
*  setting the counter (not the period) to the value written. It is not
*  advised to write to this field when the counter is running.
*
* Parameters:
*  count: value to write
*
* Return:
*  None
*
*******************************************************************************/
void EchoTimer_WriteCounter(uint32 count)
{
    EchoTimer_COUNTER_REG = (count & EchoTimer_16BIT_MASK);
}


/*******************************************************************************
* Function Name: EchoTimer_ReadCounter
********************************************************************************
*
* Summary:
*  Reads the current counter value.
*
* Parameters:
*  None
*
* Return:
*  Current counter value
*
*******************************************************************************/
uint32 EchoTimer_ReadCounter(void)
{
    return (EchoTimer_COUNTER_REG & EchoTimer_16BIT_MASK);
}


/*******************************************************************************
* Function Name: EchoTimer_SetCounterMode
********************************************************************************
*
* Summary:
*  Sets the counter mode.  Applicable to all modes except Quadrature Decoder
*  and the PWM with a pseudo random output.
*
* Parameters:
*  counterMode: Enumerated counter type values
*   Values:
*     - EchoTimer_COUNT_UP       - Counts up
*     - EchoTimer_COUNT_DOWN     - Counts down
*     - EchoTimer_COUNT_UPDOWN0  - Counts up and down. Terminal count
*                                         generated when counter reaches 0
*     - EchoTimer_COUNT_UPDOWN1  - Counts up and down. Terminal count
*                                         generated both when counter reaches 0
*                                         and period
*
* Return:
*  None
*
*******************************************************************************/
void EchoTimer_SetCounterMode(uint32 counterMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    EchoTimer_CONTROL_REG &= (uint32)~EchoTimer_UPDOWN_MASK;
    EchoTimer_CONTROL_REG |= counterMode;

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: EchoTimer_WritePeriod
********************************************************************************
*
* Summary:
*  Writes the 16 bit period register with the new period value.
*  To cause the counter to count for N cycles this register should be written
*  with N-1 (counts from 0 to period inclusive).
*
* Parameters:
*  period: Period value
*
* Return:
*  None
*
*******************************************************************************/
void EchoTimer_WritePeriod(uint32 period)
{
    EchoTimer_PERIOD_REG = (period & EchoTimer_16BIT_MASK);
}


/*******************************************************************************
* Function Name: EchoTimer_ReadPeriod
********************************************************************************
*
* Summary:
*  Reads the 16 bit period register.
*
* Parameters:
*  None
*
* Return:
*  Period value
*
*******************************************************************************/
uint32 EchoTimer_ReadPeriod(void)
{
    return (EchoTimer_PERIOD_REG & EchoTimer_16BIT_MASK);
}


/*******************************************************************************
* Function Name: EchoTimer_SetCompareSwap
********************************************************************************
*
* Summary:
*  Writes the register that controls whether the compare registers are
*  swapped. When enabled in the Timer/Counter mode(without capture) the swap
*  occurs at a TC event. In the PWM mode the swap occurs at the next TC event
*  following a hardware switch event.
*
* Parameters:
*  swapEnable
*   Values:
*     - 0 - Disable swap
*     - 1 - Enable swap
*
* Return:
*  None
*
*******************************************************************************/
void EchoTimer_SetCompareSwap(uint32 swapEnable)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    EchoTimer_CONTROL_REG &= (uint32)~EchoTimer_RELOAD_CC_MASK;
    EchoTimer_CONTROL_REG |= (swapEnable & EchoTimer_1BIT_MASK);

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: EchoTimer_WritePeriodBuf
********************************************************************************
*
* Summary:
*  Writes the 16 bit period buf register with the new period value.
*
* Parameters:
*  periodBuf: Period value
*
* Return:
*  None
*
*******************************************************************************/
void EchoTimer_WritePeriodBuf(uint32 periodBuf)
{
    EchoTimer_PERIOD_BUF_REG = (periodBuf & EchoTimer_16BIT_MASK);
}


/*******************************************************************************
* Function Name: EchoTimer_ReadPeriodBuf
********************************************************************************
*
* Summary:
*  Reads the 16 bit period buf register.
*
* Parameters:
*  None
*
* Return:
*  Period value
*
*******************************************************************************/
uint32 EchoTimer_ReadPeriodBuf(void)
{
    return (EchoTimer_PERIOD_BUF_REG & EchoTimer_16BIT_MASK);
}


/*******************************************************************************
* Function Name: EchoTimer_SetPeriodSwap
********************************************************************************
*
* Summary:
*  Writes the register that controls whether the period registers are
*  swapped. When enabled in Timer/Counter mode the swap occurs at a TC event.
*  In the PWM mode the swap occurs at the next TC event following a hardware
*  switch event.
*
* Parameters:
*  swapEnable
*   Values:
*     - 0 - Disable swap
*     - 1 - Enable swap
*
* Return:
*  None
*
*******************************************************************************/
void EchoTimer_SetPeriodSwap(uint32 swapEnable)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    EchoTimer_CONTROL_REG &= (uint32)~EchoTimer_RELOAD_PERIOD_MASK;
    EchoTimer_CONTROL_REG |= ((uint32)((swapEnable & EchoTimer_1BIT_MASK) <<
                                                            EchoTimer_RELOAD_PERIOD_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: EchoTimer_WriteCompare
********************************************************************************
*
* Summary:
*  Writes the 16 bit compare register with the new compare value. Not
*  applicable for Timer/Counter with Capture or in Quadrature Decoder modes.
*
* Parameters:
*  compare: Compare value
*
* Return:
*  None
*
*******************************************************************************/
void EchoTimer_WriteCompare(uint32 compare)
{
    #if (EchoTimer_CY_TCPWM_4000)
        uint32 currentMode;
    #endif /* (EchoTimer_CY_TCPWM_4000) */

    #if (EchoTimer_CY_TCPWM_4000)
        currentMode = ((EchoTimer_CONTROL_REG & EchoTimer_UPDOWN_MASK) >> EchoTimer_UPDOWN_SHIFT);

        if (((uint32)EchoTimer__COUNT_DOWN == currentMode) && (0xFFFFu != compare))
        {
            compare++;
        }
        else if (((uint32)EchoTimer__COUNT_UP == currentMode) && (0u != compare))
        {
            compare--;
        }
        else
        {
        }
        
    
    #endif /* (EchoTimer_CY_TCPWM_4000) */
    
    EchoTimer_COMP_CAP_REG = (compare & EchoTimer_16BIT_MASK);
}


/*******************************************************************************
* Function Name: EchoTimer_ReadCompare
********************************************************************************
*
* Summary:
*  Reads the compare register. Not applicable for Timer/Counter with Capture
*  or in Quadrature Decoder modes.
*
* Parameters:
*  None
*
* Return:
*  Compare value
*
*******************************************************************************/
uint32 EchoTimer_ReadCompare(void)
{
    #if (EchoTimer_CY_TCPWM_4000)
        uint32 currentMode;
        uint32 regVal;
    #endif /* (EchoTimer_CY_TCPWM_4000) */

    #if (EchoTimer_CY_TCPWM_4000)
        currentMode = ((EchoTimer_CONTROL_REG & EchoTimer_UPDOWN_MASK) >> EchoTimer_UPDOWN_SHIFT);
        
        regVal = EchoTimer_COMP_CAP_REG;
        
        if (((uint32)EchoTimer__COUNT_DOWN == currentMode) && (0u != regVal))
        {
            regVal--;
        }
        else if (((uint32)EchoTimer__COUNT_UP == currentMode) && (0xFFFFu != regVal))
        {
            regVal++;
        }
        else
        {
        }

        return (regVal & EchoTimer_16BIT_MASK);
    #else
        return (EchoTimer_COMP_CAP_REG & EchoTimer_16BIT_MASK);
    #endif /* (EchoTimer_CY_TCPWM_4000) */
}


/*******************************************************************************
* Function Name: EchoTimer_WriteCompareBuf
********************************************************************************
*
* Summary:
*  Writes the 16 bit compare buffer register with the new compare value. Not
*  applicable for Timer/Counter with Capture or in Quadrature Decoder modes.
*
* Parameters:
*  compareBuf: Compare value
*
* Return:
*  None
*
*******************************************************************************/
void EchoTimer_WriteCompareBuf(uint32 compareBuf)
{
    #if (EchoTimer_CY_TCPWM_4000)
        uint32 currentMode;
    #endif /* (EchoTimer_CY_TCPWM_4000) */

    #if (EchoTimer_CY_TCPWM_4000)
        currentMode = ((EchoTimer_CONTROL_REG & EchoTimer_UPDOWN_MASK) >> EchoTimer_UPDOWN_SHIFT);

        if (((uint32)EchoTimer__COUNT_DOWN == currentMode) && (0xFFFFu != compareBuf))
        {
            compareBuf++;
        }
        else if (((uint32)EchoTimer__COUNT_UP == currentMode) && (0u != compareBuf))
        {
            compareBuf --;
        }
        else
        {
        }
    #endif /* (EchoTimer_CY_TCPWM_4000) */
    
    EchoTimer_COMP_CAP_BUF_REG = (compareBuf & EchoTimer_16BIT_MASK);
}


/*******************************************************************************
* Function Name: EchoTimer_ReadCompareBuf
********************************************************************************
*
* Summary:
*  Reads the compare buffer register. Not applicable for Timer/Counter with
*  Capture or in Quadrature Decoder modes.
*
* Parameters:
*  None
*
* Return:
*  Compare buffer value
*
*******************************************************************************/
uint32 EchoTimer_ReadCompareBuf(void)
{
    #if (EchoTimer_CY_TCPWM_4000)
        uint32 currentMode;
        uint32 regVal;
    #endif /* (EchoTimer_CY_TCPWM_4000) */

    #if (EchoTimer_CY_TCPWM_4000)
        currentMode = ((EchoTimer_CONTROL_REG & EchoTimer_UPDOWN_MASK) >> EchoTimer_UPDOWN_SHIFT);

        regVal = EchoTimer_COMP_CAP_BUF_REG;
        
        if (((uint32)EchoTimer__COUNT_DOWN == currentMode) && (0u != regVal))
        {
            regVal--;
        }
        else if (((uint32)EchoTimer__COUNT_UP == currentMode) && (0xFFFFu != regVal))
        {
            regVal++;
        }
        else
        {
        }

        return (regVal & EchoTimer_16BIT_MASK);
    #else
        return (EchoTimer_COMP_CAP_BUF_REG & EchoTimer_16BIT_MASK);
    #endif /* (EchoTimer_CY_TCPWM_4000) */
}


/*******************************************************************************
* Function Name: EchoTimer_ReadCapture
********************************************************************************
*
* Summary:
*  Reads the captured counter value. This API is applicable only for
*  Timer/Counter with the capture mode and Quadrature Decoder modes.
*
* Parameters:
*  None
*
* Return:
*  Capture value
*
*******************************************************************************/
uint32 EchoTimer_ReadCapture(void)
{
    return (EchoTimer_COMP_CAP_REG & EchoTimer_16BIT_MASK);
}


/*******************************************************************************
* Function Name: EchoTimer_ReadCaptureBuf
********************************************************************************
*
* Summary:
*  Reads the capture buffer register. This API is applicable only for
*  Timer/Counter with the capture mode and Quadrature Decoder modes.
*
* Parameters:
*  None
*
* Return:
*  Capture buffer value
*
*******************************************************************************/
uint32 EchoTimer_ReadCaptureBuf(void)
{
    return (EchoTimer_COMP_CAP_BUF_REG & EchoTimer_16BIT_MASK);
}


/*******************************************************************************
* Function Name: EchoTimer_SetCaptureMode
********************************************************************************
*
* Summary:
*  Sets the capture trigger mode. For PWM mode this is the switch input.
*  This input is not applicable to the Timer/Counter without Capture and
*  Quadrature Decoder modes.
*
* Parameters:
*  triggerMode: Enumerated trigger mode value
*   Values:
*     - EchoTimer_TRIG_LEVEL     - Level
*     - EchoTimer_TRIG_RISING    - Rising edge
*     - EchoTimer_TRIG_FALLING   - Falling edge
*     - EchoTimer_TRIG_BOTH      - Both rising and falling edge
*
* Return:
*  None
*
*******************************************************************************/
void EchoTimer_SetCaptureMode(uint32 triggerMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    EchoTimer_TRIG_CONTROL1_REG &= (uint32)~EchoTimer_CAPTURE_MASK;
    EchoTimer_TRIG_CONTROL1_REG |= triggerMode;

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: EchoTimer_SetReloadMode
********************************************************************************
*
* Summary:
*  Sets the reload trigger mode. For Quadrature Decoder mode this is the index
*  input.
*
* Parameters:
*  triggerMode: Enumerated trigger mode value
*   Values:
*     - EchoTimer_TRIG_LEVEL     - Level
*     - EchoTimer_TRIG_RISING    - Rising edge
*     - EchoTimer_TRIG_FALLING   - Falling edge
*     - EchoTimer_TRIG_BOTH      - Both rising and falling edge
*
* Return:
*  None
*
*******************************************************************************/
void EchoTimer_SetReloadMode(uint32 triggerMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    EchoTimer_TRIG_CONTROL1_REG &= (uint32)~EchoTimer_RELOAD_MASK;
    EchoTimer_TRIG_CONTROL1_REG |= ((uint32)(triggerMode << EchoTimer_RELOAD_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: EchoTimer_SetStartMode
********************************************************************************
*
* Summary:
*  Sets the start trigger mode. For Quadrature Decoder mode this is the
*  phiB input.
*
* Parameters:
*  triggerMode: Enumerated trigger mode value
*   Values:
*     - EchoTimer_TRIG_LEVEL     - Level
*     - EchoTimer_TRIG_RISING    - Rising edge
*     - EchoTimer_TRIG_FALLING   - Falling edge
*     - EchoTimer_TRIG_BOTH      - Both rising and falling edge
*
* Return:
*  None
*
*******************************************************************************/
void EchoTimer_SetStartMode(uint32 triggerMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    EchoTimer_TRIG_CONTROL1_REG &= (uint32)~EchoTimer_START_MASK;
    EchoTimer_TRIG_CONTROL1_REG |= ((uint32)(triggerMode << EchoTimer_START_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: EchoTimer_SetStopMode
********************************************************************************
*
* Summary:
*  Sets the stop trigger mode. For PWM mode this is the kill input.
*
* Parameters:
*  triggerMode: Enumerated trigger mode value
*   Values:
*     - EchoTimer_TRIG_LEVEL     - Level
*     - EchoTimer_TRIG_RISING    - Rising edge
*     - EchoTimer_TRIG_FALLING   - Falling edge
*     - EchoTimer_TRIG_BOTH      - Both rising and falling edge
*
* Return:
*  None
*
*******************************************************************************/
void EchoTimer_SetStopMode(uint32 triggerMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    EchoTimer_TRIG_CONTROL1_REG &= (uint32)~EchoTimer_STOP_MASK;
    EchoTimer_TRIG_CONTROL1_REG |= ((uint32)(triggerMode << EchoTimer_STOP_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: EchoTimer_SetCountMode
********************************************************************************
*
* Summary:
*  Sets the count trigger mode. For Quadrature Decoder mode this is the phiA
*  input.
*
* Parameters:
*  triggerMode: Enumerated trigger mode value
*   Values:
*     - EchoTimer_TRIG_LEVEL     - Level
*     - EchoTimer_TRIG_RISING    - Rising edge
*     - EchoTimer_TRIG_FALLING   - Falling edge
*     - EchoTimer_TRIG_BOTH      - Both rising and falling edge
*
* Return:
*  None
*
*******************************************************************************/
void EchoTimer_SetCountMode(uint32 triggerMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    EchoTimer_TRIG_CONTROL1_REG &= (uint32)~EchoTimer_COUNT_MASK;
    EchoTimer_TRIG_CONTROL1_REG |= ((uint32)(triggerMode << EchoTimer_COUNT_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: EchoTimer_TriggerCommand
********************************************************************************
*
* Summary:
*  Triggers the designated command to occur on the designated TCPWM instances.
*  The mask can be used to apply this command simultaneously to more than one
*  instance.  This allows multiple TCPWM instances to be synchronized.
*
* Parameters:
*  mask: A combination of mask bits for each instance of the TCPWM that the
*        command should apply to.  This function from one instance can be used
*        to apply the command to any of the instances in the design.
*        The mask value for a specific instance is available with the MASK
*        define.
*  command: Enumerated command values. Capture command only applicable for
*           Timer/Counter with Capture and PWM modes.
*   Values:
*     - EchoTimer_CMD_CAPTURE    - Trigger Capture command
*     - EchoTimer_CMD_RELOAD     - Trigger Reload command
*     - EchoTimer_CMD_STOP       - Trigger Stop command
*     - EchoTimer_CMD_START      - Trigger Start command
*
* Return:
*  None
*
*******************************************************************************/
void EchoTimer_TriggerCommand(uint32 mask, uint32 command)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    EchoTimer_COMMAND_REG = ((uint32)(mask << command));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: EchoTimer_ReadStatus
********************************************************************************
*
* Summary:
*  Reads the status of the EchoTimer.
*
* Parameters:
*  None
*
* Return:
*  Status
*   Values:
*     - EchoTimer_STATUS_DOWN    - Set if counting down
*     - EchoTimer_STATUS_RUNNING - Set if counter is running
*
*******************************************************************************/
uint32 EchoTimer_ReadStatus(void)
{
    return ((EchoTimer_STATUS_REG >> EchoTimer_RUNNING_STATUS_SHIFT) |
            (EchoTimer_STATUS_REG & EchoTimer_STATUS_DOWN));
}


/*******************************************************************************
* Function Name: EchoTimer_SetInterruptMode
********************************************************************************
*
* Summary:
*  Sets the interrupt mask to control which interrupt
*  requests generate the interrupt signal.
*
* Parameters:
*   interruptMask: Mask of bits to be enabled
*   Values:
*     - EchoTimer_INTR_MASK_TC       - Terminal count mask
*     - EchoTimer_INTR_MASK_CC_MATCH - Compare count / capture mask
*
* Return:
*  None
*
*******************************************************************************/
void EchoTimer_SetInterruptMode(uint32 interruptMask)
{
    EchoTimer_INTERRUPT_MASK_REG =  interruptMask;
}


/*******************************************************************************
* Function Name: EchoTimer_GetInterruptSourceMasked
********************************************************************************
*
* Summary:
*  Gets the interrupt requests masked by the interrupt mask.
*
* Parameters:
*   None
*
* Return:
*  Masked interrupt source
*   Values:
*     - EchoTimer_INTR_MASK_TC       - Terminal count mask
*     - EchoTimer_INTR_MASK_CC_MATCH - Compare count / capture mask
*
*******************************************************************************/
uint32 EchoTimer_GetInterruptSourceMasked(void)
{
    return (EchoTimer_INTERRUPT_MASKED_REG);
}


/*******************************************************************************
* Function Name: EchoTimer_GetInterruptSource
********************************************************************************
*
* Summary:
*  Gets the interrupt requests (without masking).
*
* Parameters:
*  None
*
* Return:
*  Interrupt request value
*   Values:
*     - EchoTimer_INTR_MASK_TC       - Terminal count mask
*     - EchoTimer_INTR_MASK_CC_MATCH - Compare count / capture mask
*
*******************************************************************************/
uint32 EchoTimer_GetInterruptSource(void)
{
    return (EchoTimer_INTERRUPT_REQ_REG);
}


/*******************************************************************************
* Function Name: EchoTimer_ClearInterrupt
********************************************************************************
*
* Summary:
*  Clears the interrupt request.
*
* Parameters:
*   interruptMask: Mask of interrupts to clear
*   Values:
*     - EchoTimer_INTR_MASK_TC       - Terminal count mask
*     - EchoTimer_INTR_MASK_CC_MATCH - Compare count / capture mask
*
* Return:
*  None
*
*******************************************************************************/
void EchoTimer_ClearInterrupt(uint32 interruptMask)
{
    EchoTimer_INTERRUPT_REQ_REG = interruptMask;
}


/*******************************************************************************
* Function Name: EchoTimer_SetInterrupt
********************************************************************************
*
* Summary:
*  Sets a software interrupt request.
*
* Parameters:
*   interruptMask: Mask of interrupts to set
*   Values:
*     - EchoTimer_INTR_MASK_TC       - Terminal count mask
*     - EchoTimer_INTR_MASK_CC_MATCH - Compare count / capture mask
*
* Return:
*  None
*
*******************************************************************************/
void EchoTimer_SetInterrupt(uint32 interruptMask)
{
    EchoTimer_INTERRUPT_SET_REG = interruptMask;
}


/* [] END OF FILE */
