/*******************************************************************************
* File Name: EchoTimer.h
* Version 2.0
*
* Description:
*  This file provides constants and parameter values for the EchoTimer
*  component.
*
* Note:
*  None
*
********************************************************************************
* Copyright 2013-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_TCPWM_EchoTimer_H)
#define CY_TCPWM_EchoTimer_H


#include "CyLib.h"
#include "cytypes.h"
#include "cyfitter.h"


/*******************************************************************************
* Internal Type defines
*******************************************************************************/

/* Structure to save state before go to sleep */
typedef struct
{
    uint8  enableState;
} EchoTimer_BACKUP_STRUCT;


/*******************************************************************************
* Variables
*******************************************************************************/
extern uint8  EchoTimer_initVar;


/***************************************
*   Conditional Compilation Parameters
****************************************/

#define EchoTimer_CY_TCPWM_V2                    (CYIPBLOCK_m0s8tcpwm_VERSION == 2u)
#define EchoTimer_CY_TCPWM_4000                  (CY_PSOC4_4000)

/* TCPWM Configuration */
#define EchoTimer_CONFIG                         (1lu)

/* Quad Mode */
/* Parameters */
#define EchoTimer_QUAD_ENCODING_MODES            (0lu)

/* Signal modes */
#define EchoTimer_QUAD_INDEX_SIGNAL_MODE         (0lu)
#define EchoTimer_QUAD_PHIA_SIGNAL_MODE          (3lu)
#define EchoTimer_QUAD_PHIB_SIGNAL_MODE          (3lu)
#define EchoTimer_QUAD_STOP_SIGNAL_MODE          (0lu)

/* Signal present */
#define EchoTimer_QUAD_INDEX_SIGNAL_PRESENT      (0lu)
#define EchoTimer_QUAD_STOP_SIGNAL_PRESENT       (0lu)

/* Interrupt Mask */
#define EchoTimer_QUAD_INTERRUPT_MASK            (1lu)

/* Timer/Counter Mode */
/* Parameters */
#define EchoTimer_TC_RUN_MODE                    (0lu)
#define EchoTimer_TC_COUNTER_MODE                (1lu)
#define EchoTimer_TC_COMP_CAP_MODE               (2lu)
#define EchoTimer_TC_PRESCALER                   (0lu)

/* Signal modes */
#define EchoTimer_TC_RELOAD_SIGNAL_MODE          (0lu)
#define EchoTimer_TC_COUNT_SIGNAL_MODE           (3lu)
#define EchoTimer_TC_START_SIGNAL_MODE           (0lu)
#define EchoTimer_TC_STOP_SIGNAL_MODE            (0lu)
#define EchoTimer_TC_CAPTURE_SIGNAL_MODE         (0lu)

/* Signal present */
#define EchoTimer_TC_RELOAD_SIGNAL_PRESENT       (0lu)
#define EchoTimer_TC_COUNT_SIGNAL_PRESENT        (0lu)
#define EchoTimer_TC_START_SIGNAL_PRESENT        (0lu)
#define EchoTimer_TC_STOP_SIGNAL_PRESENT         (0lu)
#define EchoTimer_TC_CAPTURE_SIGNAL_PRESENT      (0lu)

/* Interrupt Mask */
#define EchoTimer_TC_INTERRUPT_MASK              (0lu)

/* PWM Mode */
/* Parameters */
#define EchoTimer_PWM_KILL_EVENT                 (0lu)
#define EchoTimer_PWM_STOP_EVENT                 (0lu)
#define EchoTimer_PWM_MODE                       (4lu)
#define EchoTimer_PWM_OUT_N_INVERT               (0lu)
#define EchoTimer_PWM_OUT_INVERT                 (0lu)
#define EchoTimer_PWM_ALIGN                      (0lu)
#define EchoTimer_PWM_RUN_MODE                   (0lu)
#define EchoTimer_PWM_DEAD_TIME_CYCLE            (0lu)
#define EchoTimer_PWM_PRESCALER                  (0lu)

/* Signal modes */
#define EchoTimer_PWM_RELOAD_SIGNAL_MODE         (0lu)
#define EchoTimer_PWM_COUNT_SIGNAL_MODE          (3lu)
#define EchoTimer_PWM_START_SIGNAL_MODE          (0lu)
#define EchoTimer_PWM_STOP_SIGNAL_MODE           (0lu)
#define EchoTimer_PWM_SWITCH_SIGNAL_MODE         (0lu)

/* Signal present */
#define EchoTimer_PWM_RELOAD_SIGNAL_PRESENT      (0lu)
#define EchoTimer_PWM_COUNT_SIGNAL_PRESENT       (0lu)
#define EchoTimer_PWM_START_SIGNAL_PRESENT       (0lu)
#define EchoTimer_PWM_STOP_SIGNAL_PRESENT        (0lu)
#define EchoTimer_PWM_SWITCH_SIGNAL_PRESENT      (0lu)

/* Interrupt Mask */
#define EchoTimer_PWM_INTERRUPT_MASK             (1lu)


/***************************************
*    Initial Parameter Constants
***************************************/

/* Timer/Counter Mode */
#define EchoTimer_TC_PERIOD_VALUE                (65535lu)
#define EchoTimer_TC_COMPARE_VALUE               (65535lu)
#define EchoTimer_TC_COMPARE_BUF_VALUE           (65535lu)
#define EchoTimer_TC_COMPARE_SWAP                (0lu)

/* PWM Mode */
#define EchoTimer_PWM_PERIOD_VALUE               (65535lu)
#define EchoTimer_PWM_PERIOD_BUF_VALUE           (65535lu)
#define EchoTimer_PWM_PERIOD_SWAP                (0lu)
#define EchoTimer_PWM_COMPARE_VALUE              (65535lu)
#define EchoTimer_PWM_COMPARE_BUF_VALUE          (65535lu)
#define EchoTimer_PWM_COMPARE_SWAP               (0lu)


/***************************************
*    Enumerated Types and Parameters
***************************************/

#define EchoTimer__LEFT 0
#define EchoTimer__RIGHT 1
#define EchoTimer__CENTER 2
#define EchoTimer__ASYMMETRIC 3

#define EchoTimer__X1 0
#define EchoTimer__X2 1
#define EchoTimer__X4 2

#define EchoTimer__PWM 4
#define EchoTimer__PWM_DT 5
#define EchoTimer__PWM_PR 6

#define EchoTimer__INVERSE 1
#define EchoTimer__DIRECT 0

#define EchoTimer__CAPTURE 2
#define EchoTimer__COMPARE 0

#define EchoTimer__TRIG_LEVEL 3
#define EchoTimer__TRIG_RISING 0
#define EchoTimer__TRIG_FALLING 1
#define EchoTimer__TRIG_BOTH 2

#define EchoTimer__INTR_MASK_TC 1
#define EchoTimer__INTR_MASK_CC_MATCH 2
#define EchoTimer__INTR_MASK_NONE 0
#define EchoTimer__INTR_MASK_TC_CC 3

#define EchoTimer__UNCONFIG 8
#define EchoTimer__TIMER 1
#define EchoTimer__QUAD 3
#define EchoTimer__PWM_SEL 7

#define EchoTimer__COUNT_UP 0
#define EchoTimer__COUNT_DOWN 1
#define EchoTimer__COUNT_UPDOWN0 2
#define EchoTimer__COUNT_UPDOWN1 3


/* Prescaler */
#define EchoTimer_PRESCALE_DIVBY1                ((uint32)(0u << EchoTimer_PRESCALER_SHIFT))
#define EchoTimer_PRESCALE_DIVBY2                ((uint32)(1u << EchoTimer_PRESCALER_SHIFT))
#define EchoTimer_PRESCALE_DIVBY4                ((uint32)(2u << EchoTimer_PRESCALER_SHIFT))
#define EchoTimer_PRESCALE_DIVBY8                ((uint32)(3u << EchoTimer_PRESCALER_SHIFT))
#define EchoTimer_PRESCALE_DIVBY16               ((uint32)(4u << EchoTimer_PRESCALER_SHIFT))
#define EchoTimer_PRESCALE_DIVBY32               ((uint32)(5u << EchoTimer_PRESCALER_SHIFT))
#define EchoTimer_PRESCALE_DIVBY64               ((uint32)(6u << EchoTimer_PRESCALER_SHIFT))
#define EchoTimer_PRESCALE_DIVBY128              ((uint32)(7u << EchoTimer_PRESCALER_SHIFT))

/* TCPWM set modes */
#define EchoTimer_MODE_TIMER_COMPARE             ((uint32)(EchoTimer__COMPARE         <<  \
                                                                  EchoTimer_MODE_SHIFT))
#define EchoTimer_MODE_TIMER_CAPTURE             ((uint32)(EchoTimer__CAPTURE         <<  \
                                                                  EchoTimer_MODE_SHIFT))
#define EchoTimer_MODE_QUAD                      ((uint32)(EchoTimer__QUAD            <<  \
                                                                  EchoTimer_MODE_SHIFT))
#define EchoTimer_MODE_PWM                       ((uint32)(EchoTimer__PWM             <<  \
                                                                  EchoTimer_MODE_SHIFT))
#define EchoTimer_MODE_PWM_DT                    ((uint32)(EchoTimer__PWM_DT          <<  \
                                                                  EchoTimer_MODE_SHIFT))
#define EchoTimer_MODE_PWM_PR                    ((uint32)(EchoTimer__PWM_PR          <<  \
                                                                  EchoTimer_MODE_SHIFT))

/* Quad Modes */
#define EchoTimer_MODE_X1                        ((uint32)(EchoTimer__X1              <<  \
                                                                  EchoTimer_QUAD_MODE_SHIFT))
#define EchoTimer_MODE_X2                        ((uint32)(EchoTimer__X2              <<  \
                                                                  EchoTimer_QUAD_MODE_SHIFT))
#define EchoTimer_MODE_X4                        ((uint32)(EchoTimer__X4              <<  \
                                                                  EchoTimer_QUAD_MODE_SHIFT))

/* Counter modes */
#define EchoTimer_COUNT_UP                       ((uint32)(EchoTimer__COUNT_UP        <<  \
                                                                  EchoTimer_UPDOWN_SHIFT))
#define EchoTimer_COUNT_DOWN                     ((uint32)(EchoTimer__COUNT_DOWN      <<  \
                                                                  EchoTimer_UPDOWN_SHIFT))
#define EchoTimer_COUNT_UPDOWN0                  ((uint32)(EchoTimer__COUNT_UPDOWN0   <<  \
                                                                  EchoTimer_UPDOWN_SHIFT))
#define EchoTimer_COUNT_UPDOWN1                  ((uint32)(EchoTimer__COUNT_UPDOWN1   <<  \
                                                                  EchoTimer_UPDOWN_SHIFT))

/* PWM output invert */
#define EchoTimer_INVERT_LINE                    ((uint32)(EchoTimer__INVERSE         <<  \
                                                                  EchoTimer_INV_OUT_SHIFT))
#define EchoTimer_INVERT_LINE_N                  ((uint32)(EchoTimer__INVERSE         <<  \
                                                                  EchoTimer_INV_COMPL_OUT_SHIFT))

/* Trigger modes */
#define EchoTimer_TRIG_RISING                    ((uint32)EchoTimer__TRIG_RISING)
#define EchoTimer_TRIG_FALLING                   ((uint32)EchoTimer__TRIG_FALLING)
#define EchoTimer_TRIG_BOTH                      ((uint32)EchoTimer__TRIG_BOTH)
#define EchoTimer_TRIG_LEVEL                     ((uint32)EchoTimer__TRIG_LEVEL)

/* Interrupt mask */
#define EchoTimer_INTR_MASK_TC                   ((uint32)EchoTimer__INTR_MASK_TC)
#define EchoTimer_INTR_MASK_CC_MATCH             ((uint32)EchoTimer__INTR_MASK_CC_MATCH)

/* PWM Output Controls */
#define EchoTimer_CC_MATCH_SET                   (0x00u)
#define EchoTimer_CC_MATCH_CLEAR                 (0x01u)
#define EchoTimer_CC_MATCH_INVERT                (0x02u)
#define EchoTimer_CC_MATCH_NO_CHANGE             (0x03u)
#define EchoTimer_OVERLOW_SET                    (0x00u)
#define EchoTimer_OVERLOW_CLEAR                  (0x04u)
#define EchoTimer_OVERLOW_INVERT                 (0x08u)
#define EchoTimer_OVERLOW_NO_CHANGE              (0x0Cu)
#define EchoTimer_UNDERFLOW_SET                  (0x00u)
#define EchoTimer_UNDERFLOW_CLEAR                (0x10u)
#define EchoTimer_UNDERFLOW_INVERT               (0x20u)
#define EchoTimer_UNDERFLOW_NO_CHANGE            (0x30u)

/* PWM Align */
#define EchoTimer_PWM_MODE_LEFT                  (EchoTimer_CC_MATCH_CLEAR        |   \
                                                         EchoTimer_OVERLOW_SET           |   \
                                                         EchoTimer_UNDERFLOW_NO_CHANGE)
#define EchoTimer_PWM_MODE_RIGHT                 (EchoTimer_CC_MATCH_SET          |   \
                                                         EchoTimer_OVERLOW_NO_CHANGE     |   \
                                                         EchoTimer_UNDERFLOW_CLEAR)
#define EchoTimer_PWM_MODE_ASYM                  (EchoTimer_CC_MATCH_INVERT       |   \
                                                         EchoTimer_OVERLOW_SET           |   \
                                                         EchoTimer_UNDERFLOW_CLEAR)

#if (EchoTimer_CY_TCPWM_V2)
    #if(EchoTimer_CY_TCPWM_4000)
        #define EchoTimer_PWM_MODE_CENTER                (EchoTimer_CC_MATCH_INVERT       |   \
                                                                 EchoTimer_OVERLOW_NO_CHANGE     |   \
                                                                 EchoTimer_UNDERFLOW_CLEAR)
    #else
        #define EchoTimer_PWM_MODE_CENTER                (EchoTimer_CC_MATCH_INVERT       |   \
                                                                 EchoTimer_OVERLOW_SET           |   \
                                                                 EchoTimer_UNDERFLOW_CLEAR)
    #endif /* (EchoTimer_CY_TCPWM_4000) */
#else
    #define EchoTimer_PWM_MODE_CENTER                (EchoTimer_CC_MATCH_INVERT       |   \
                                                             EchoTimer_OVERLOW_NO_CHANGE     |   \
                                                             EchoTimer_UNDERFLOW_CLEAR)
#endif /* (EchoTimer_CY_TCPWM_NEW) */

/* Command operations without condition */
#define EchoTimer_CMD_CAPTURE                    (0u)
#define EchoTimer_CMD_RELOAD                     (8u)
#define EchoTimer_CMD_STOP                       (16u)
#define EchoTimer_CMD_START                      (24u)

/* Status */
#define EchoTimer_STATUS_DOWN                    (1u)
#define EchoTimer_STATUS_RUNNING                 (2u)


/***************************************
*        Function Prototypes
****************************************/

void   EchoTimer_Init(void);
void   EchoTimer_Enable(void);
void   EchoTimer_Start(void);
void   EchoTimer_Stop(void);

void   EchoTimer_SetMode(uint32 mode);
void   EchoTimer_SetCounterMode(uint32 counterMode);
void   EchoTimer_SetPWMMode(uint32 modeMask);
void   EchoTimer_SetQDMode(uint32 qdMode);

void   EchoTimer_SetPrescaler(uint32 prescaler);
void   EchoTimer_TriggerCommand(uint32 mask, uint32 command);
void   EchoTimer_SetOneShot(uint32 oneShotEnable);
uint32 EchoTimer_ReadStatus(void);

void   EchoTimer_SetPWMSyncKill(uint32 syncKillEnable);
void   EchoTimer_SetPWMStopOnKill(uint32 stopOnKillEnable);
void   EchoTimer_SetPWMDeadTime(uint32 deadTime);
void   EchoTimer_SetPWMInvert(uint32 mask);

void   EchoTimer_SetInterruptMode(uint32 interruptMask);
uint32 EchoTimer_GetInterruptSourceMasked(void);
uint32 EchoTimer_GetInterruptSource(void);
void   EchoTimer_ClearInterrupt(uint32 interruptMask);
void   EchoTimer_SetInterrupt(uint32 interruptMask);

void   EchoTimer_WriteCounter(uint32 count);
uint32 EchoTimer_ReadCounter(void);

uint32 EchoTimer_ReadCapture(void);
uint32 EchoTimer_ReadCaptureBuf(void);

void   EchoTimer_WritePeriod(uint32 period);
uint32 EchoTimer_ReadPeriod(void);
void   EchoTimer_WritePeriodBuf(uint32 periodBuf);
uint32 EchoTimer_ReadPeriodBuf(void);

void   EchoTimer_WriteCompare(uint32 compare);
uint32 EchoTimer_ReadCompare(void);
void   EchoTimer_WriteCompareBuf(uint32 compareBuf);
uint32 EchoTimer_ReadCompareBuf(void);

void   EchoTimer_SetPeriodSwap(uint32 swapEnable);
void   EchoTimer_SetCompareSwap(uint32 swapEnable);

void   EchoTimer_SetCaptureMode(uint32 triggerMode);
void   EchoTimer_SetReloadMode(uint32 triggerMode);
void   EchoTimer_SetStartMode(uint32 triggerMode);
void   EchoTimer_SetStopMode(uint32 triggerMode);
void   EchoTimer_SetCountMode(uint32 triggerMode);

void   EchoTimer_SaveConfig(void);
void   EchoTimer_RestoreConfig(void);
void   EchoTimer_Sleep(void);
void   EchoTimer_Wakeup(void);


/***************************************
*             Registers
***************************************/

#define EchoTimer_BLOCK_CONTROL_REG              (*(reg32 *) EchoTimer_cy_m0s8_tcpwm_1__TCPWM_CTRL )
#define EchoTimer_BLOCK_CONTROL_PTR              ( (reg32 *) EchoTimer_cy_m0s8_tcpwm_1__TCPWM_CTRL )
#define EchoTimer_COMMAND_REG                    (*(reg32 *) EchoTimer_cy_m0s8_tcpwm_1__TCPWM_CMD )
#define EchoTimer_COMMAND_PTR                    ( (reg32 *) EchoTimer_cy_m0s8_tcpwm_1__TCPWM_CMD )
#define EchoTimer_INTRRUPT_CAUSE_REG             (*(reg32 *) EchoTimer_cy_m0s8_tcpwm_1__TCPWM_INTR_CAUSE )
#define EchoTimer_INTRRUPT_CAUSE_PTR             ( (reg32 *) EchoTimer_cy_m0s8_tcpwm_1__TCPWM_INTR_CAUSE )
#define EchoTimer_CONTROL_REG                    (*(reg32 *) EchoTimer_cy_m0s8_tcpwm_1__CTRL )
#define EchoTimer_CONTROL_PTR                    ( (reg32 *) EchoTimer_cy_m0s8_tcpwm_1__CTRL )
#define EchoTimer_STATUS_REG                     (*(reg32 *) EchoTimer_cy_m0s8_tcpwm_1__STATUS )
#define EchoTimer_STATUS_PTR                     ( (reg32 *) EchoTimer_cy_m0s8_tcpwm_1__STATUS )
#define EchoTimer_COUNTER_REG                    (*(reg32 *) EchoTimer_cy_m0s8_tcpwm_1__COUNTER )
#define EchoTimer_COUNTER_PTR                    ( (reg32 *) EchoTimer_cy_m0s8_tcpwm_1__COUNTER )
#define EchoTimer_COMP_CAP_REG                   (*(reg32 *) EchoTimer_cy_m0s8_tcpwm_1__CC )
#define EchoTimer_COMP_CAP_PTR                   ( (reg32 *) EchoTimer_cy_m0s8_tcpwm_1__CC )
#define EchoTimer_COMP_CAP_BUF_REG               (*(reg32 *) EchoTimer_cy_m0s8_tcpwm_1__CC_BUFF )
#define EchoTimer_COMP_CAP_BUF_PTR               ( (reg32 *) EchoTimer_cy_m0s8_tcpwm_1__CC_BUFF )
#define EchoTimer_PERIOD_REG                     (*(reg32 *) EchoTimer_cy_m0s8_tcpwm_1__PERIOD )
#define EchoTimer_PERIOD_PTR                     ( (reg32 *) EchoTimer_cy_m0s8_tcpwm_1__PERIOD )
#define EchoTimer_PERIOD_BUF_REG                 (*(reg32 *) EchoTimer_cy_m0s8_tcpwm_1__PERIOD_BUFF )
#define EchoTimer_PERIOD_BUF_PTR                 ( (reg32 *) EchoTimer_cy_m0s8_tcpwm_1__PERIOD_BUFF )
#define EchoTimer_TRIG_CONTROL0_REG              (*(reg32 *) EchoTimer_cy_m0s8_tcpwm_1__TR_CTRL0 )
#define EchoTimer_TRIG_CONTROL0_PTR              ( (reg32 *) EchoTimer_cy_m0s8_tcpwm_1__TR_CTRL0 )
#define EchoTimer_TRIG_CONTROL1_REG              (*(reg32 *) EchoTimer_cy_m0s8_tcpwm_1__TR_CTRL1 )
#define EchoTimer_TRIG_CONTROL1_PTR              ( (reg32 *) EchoTimer_cy_m0s8_tcpwm_1__TR_CTRL1 )
#define EchoTimer_TRIG_CONTROL2_REG              (*(reg32 *) EchoTimer_cy_m0s8_tcpwm_1__TR_CTRL2 )
#define EchoTimer_TRIG_CONTROL2_PTR              ( (reg32 *) EchoTimer_cy_m0s8_tcpwm_1__TR_CTRL2 )
#define EchoTimer_INTERRUPT_REQ_REG              (*(reg32 *) EchoTimer_cy_m0s8_tcpwm_1__INTR )
#define EchoTimer_INTERRUPT_REQ_PTR              ( (reg32 *) EchoTimer_cy_m0s8_tcpwm_1__INTR )
#define EchoTimer_INTERRUPT_SET_REG              (*(reg32 *) EchoTimer_cy_m0s8_tcpwm_1__INTR_SET )
#define EchoTimer_INTERRUPT_SET_PTR              ( (reg32 *) EchoTimer_cy_m0s8_tcpwm_1__INTR_SET )
#define EchoTimer_INTERRUPT_MASK_REG             (*(reg32 *) EchoTimer_cy_m0s8_tcpwm_1__INTR_MASK )
#define EchoTimer_INTERRUPT_MASK_PTR             ( (reg32 *) EchoTimer_cy_m0s8_tcpwm_1__INTR_MASK )
#define EchoTimer_INTERRUPT_MASKED_REG           (*(reg32 *) EchoTimer_cy_m0s8_tcpwm_1__INTR_MASKED )
#define EchoTimer_INTERRUPT_MASKED_PTR           ( (reg32 *) EchoTimer_cy_m0s8_tcpwm_1__INTR_MASKED )


/***************************************
*       Registers Constants
***************************************/

/* Mask */
#define EchoTimer_MASK                           ((uint32)EchoTimer_cy_m0s8_tcpwm_1__TCPWM_CTRL_MASK)

/* Shift constants for control register */
#define EchoTimer_RELOAD_CC_SHIFT                (0u)
#define EchoTimer_RELOAD_PERIOD_SHIFT            (1u)
#define EchoTimer_PWM_SYNC_KILL_SHIFT            (2u)
#define EchoTimer_PWM_STOP_KILL_SHIFT            (3u)
#define EchoTimer_PRESCALER_SHIFT                (8u)
#define EchoTimer_UPDOWN_SHIFT                   (16u)
#define EchoTimer_ONESHOT_SHIFT                  (18u)
#define EchoTimer_QUAD_MODE_SHIFT                (20u)
#define EchoTimer_INV_OUT_SHIFT                  (20u)
#define EchoTimer_INV_COMPL_OUT_SHIFT            (21u)
#define EchoTimer_MODE_SHIFT                     (24u)

/* Mask constants for control register */
#define EchoTimer_RELOAD_CC_MASK                 ((uint32)(EchoTimer_1BIT_MASK        <<  \
                                                                            EchoTimer_RELOAD_CC_SHIFT))
#define EchoTimer_RELOAD_PERIOD_MASK             ((uint32)(EchoTimer_1BIT_MASK        <<  \
                                                                            EchoTimer_RELOAD_PERIOD_SHIFT))
#define EchoTimer_PWM_SYNC_KILL_MASK             ((uint32)(EchoTimer_1BIT_MASK        <<  \
                                                                            EchoTimer_PWM_SYNC_KILL_SHIFT))
#define EchoTimer_PWM_STOP_KILL_MASK             ((uint32)(EchoTimer_1BIT_MASK        <<  \
                                                                            EchoTimer_PWM_STOP_KILL_SHIFT))
#define EchoTimer_PRESCALER_MASK                 ((uint32)(EchoTimer_8BIT_MASK        <<  \
                                                                            EchoTimer_PRESCALER_SHIFT))
#define EchoTimer_UPDOWN_MASK                    ((uint32)(EchoTimer_2BIT_MASK        <<  \
                                                                            EchoTimer_UPDOWN_SHIFT))
#define EchoTimer_ONESHOT_MASK                   ((uint32)(EchoTimer_1BIT_MASK        <<  \
                                                                            EchoTimer_ONESHOT_SHIFT))
#define EchoTimer_QUAD_MODE_MASK                 ((uint32)(EchoTimer_3BIT_MASK        <<  \
                                                                            EchoTimer_QUAD_MODE_SHIFT))
#define EchoTimer_INV_OUT_MASK                   ((uint32)(EchoTimer_2BIT_MASK        <<  \
                                                                            EchoTimer_INV_OUT_SHIFT))
#define EchoTimer_MODE_MASK                      ((uint32)(EchoTimer_3BIT_MASK        <<  \
                                                                            EchoTimer_MODE_SHIFT))

/* Shift constants for trigger control register 1 */
#define EchoTimer_CAPTURE_SHIFT                  (0u)
#define EchoTimer_COUNT_SHIFT                    (2u)
#define EchoTimer_RELOAD_SHIFT                   (4u)
#define EchoTimer_STOP_SHIFT                     (6u)
#define EchoTimer_START_SHIFT                    (8u)

/* Mask constants for trigger control register 1 */
#define EchoTimer_CAPTURE_MASK                   ((uint32)(EchoTimer_2BIT_MASK        <<  \
                                                                  EchoTimer_CAPTURE_SHIFT))
#define EchoTimer_COUNT_MASK                     ((uint32)(EchoTimer_2BIT_MASK        <<  \
                                                                  EchoTimer_COUNT_SHIFT))
#define EchoTimer_RELOAD_MASK                    ((uint32)(EchoTimer_2BIT_MASK        <<  \
                                                                  EchoTimer_RELOAD_SHIFT))
#define EchoTimer_STOP_MASK                      ((uint32)(EchoTimer_2BIT_MASK        <<  \
                                                                  EchoTimer_STOP_SHIFT))
#define EchoTimer_START_MASK                     ((uint32)(EchoTimer_2BIT_MASK        <<  \
                                                                  EchoTimer_START_SHIFT))

/* MASK */
#define EchoTimer_1BIT_MASK                      ((uint32)0x01u)
#define EchoTimer_2BIT_MASK                      ((uint32)0x03u)
#define EchoTimer_3BIT_MASK                      ((uint32)0x07u)
#define EchoTimer_6BIT_MASK                      ((uint32)0x3Fu)
#define EchoTimer_8BIT_MASK                      ((uint32)0xFFu)
#define EchoTimer_16BIT_MASK                     ((uint32)0xFFFFu)

/* Shift constant for status register */
#define EchoTimer_RUNNING_STATUS_SHIFT           (30u)


/***************************************
*    Initial Constants
***************************************/

#define EchoTimer_CTRL_QUAD_BASE_CONFIG                                                          \
        (((uint32)(EchoTimer_QUAD_ENCODING_MODES     << EchoTimer_QUAD_MODE_SHIFT))       |\
         ((uint32)(EchoTimer_CONFIG                  << EchoTimer_MODE_SHIFT)))

#define EchoTimer_CTRL_PWM_BASE_CONFIG                                                           \
        (((uint32)(EchoTimer_PWM_STOP_EVENT          << EchoTimer_PWM_STOP_KILL_SHIFT))   |\
         ((uint32)(EchoTimer_PWM_OUT_INVERT          << EchoTimer_INV_OUT_SHIFT))         |\
         ((uint32)(EchoTimer_PWM_OUT_N_INVERT        << EchoTimer_INV_COMPL_OUT_SHIFT))   |\
         ((uint32)(EchoTimer_PWM_MODE                << EchoTimer_MODE_SHIFT)))

#define EchoTimer_CTRL_PWM_RUN_MODE                                                              \
            ((uint32)(EchoTimer_PWM_RUN_MODE         << EchoTimer_ONESHOT_SHIFT))
            
#define EchoTimer_CTRL_PWM_ALIGN                                                                 \
            ((uint32)(EchoTimer_PWM_ALIGN            << EchoTimer_UPDOWN_SHIFT))

#define EchoTimer_CTRL_PWM_KILL_EVENT                                                            \
             ((uint32)(EchoTimer_PWM_KILL_EVENT      << EchoTimer_PWM_SYNC_KILL_SHIFT))

#define EchoTimer_CTRL_PWM_DEAD_TIME_CYCLE                                                       \
            ((uint32)(EchoTimer_PWM_DEAD_TIME_CYCLE  << EchoTimer_PRESCALER_SHIFT))

#define EchoTimer_CTRL_PWM_PRESCALER                                                             \
            ((uint32)(EchoTimer_PWM_PRESCALER        << EchoTimer_PRESCALER_SHIFT))

#define EchoTimer_CTRL_TIMER_BASE_CONFIG                                                         \
        (((uint32)(EchoTimer_TC_PRESCALER            << EchoTimer_PRESCALER_SHIFT))       |\
         ((uint32)(EchoTimer_TC_COUNTER_MODE         << EchoTimer_UPDOWN_SHIFT))          |\
         ((uint32)(EchoTimer_TC_RUN_MODE             << EchoTimer_ONESHOT_SHIFT))         |\
         ((uint32)(EchoTimer_TC_COMP_CAP_MODE        << EchoTimer_MODE_SHIFT)))
        
#define EchoTimer_QUAD_SIGNALS_MODES                                                             \
        (((uint32)(EchoTimer_QUAD_PHIA_SIGNAL_MODE   << EchoTimer_COUNT_SHIFT))           |\
         ((uint32)(EchoTimer_QUAD_INDEX_SIGNAL_MODE  << EchoTimer_RELOAD_SHIFT))          |\
         ((uint32)(EchoTimer_QUAD_STOP_SIGNAL_MODE   << EchoTimer_STOP_SHIFT))            |\
         ((uint32)(EchoTimer_QUAD_PHIB_SIGNAL_MODE   << EchoTimer_START_SHIFT)))

#define EchoTimer_PWM_SIGNALS_MODES                                                              \
        (((uint32)(EchoTimer_PWM_SWITCH_SIGNAL_MODE  << EchoTimer_CAPTURE_SHIFT))         |\
         ((uint32)(EchoTimer_PWM_COUNT_SIGNAL_MODE   << EchoTimer_COUNT_SHIFT))           |\
         ((uint32)(EchoTimer_PWM_RELOAD_SIGNAL_MODE  << EchoTimer_RELOAD_SHIFT))          |\
         ((uint32)(EchoTimer_PWM_STOP_SIGNAL_MODE    << EchoTimer_STOP_SHIFT))            |\
         ((uint32)(EchoTimer_PWM_START_SIGNAL_MODE   << EchoTimer_START_SHIFT)))

#define EchoTimer_TIMER_SIGNALS_MODES                                                            \
        (((uint32)(EchoTimer_TC_CAPTURE_SIGNAL_MODE  << EchoTimer_CAPTURE_SHIFT))         |\
         ((uint32)(EchoTimer_TC_COUNT_SIGNAL_MODE    << EchoTimer_COUNT_SHIFT))           |\
         ((uint32)(EchoTimer_TC_RELOAD_SIGNAL_MODE   << EchoTimer_RELOAD_SHIFT))          |\
         ((uint32)(EchoTimer_TC_STOP_SIGNAL_MODE     << EchoTimer_STOP_SHIFT))            |\
         ((uint32)(EchoTimer_TC_START_SIGNAL_MODE    << EchoTimer_START_SHIFT)))
        
#define EchoTimer_TIMER_UPDOWN_CNT_USED                                                          \
                ((EchoTimer__COUNT_UPDOWN0 == EchoTimer_TC_COUNTER_MODE)                  ||\
                 (EchoTimer__COUNT_UPDOWN1 == EchoTimer_TC_COUNTER_MODE))

#define EchoTimer_PWM_UPDOWN_CNT_USED                                                            \
                ((EchoTimer__CENTER == EchoTimer_PWM_ALIGN)                               ||\
                 (EchoTimer__ASYMMETRIC == EchoTimer_PWM_ALIGN))               
        
#define EchoTimer_PWM_PR_INIT_VALUE              (1u)
#define EchoTimer_QUAD_PERIOD_INIT_VALUE         (0x8000u)



#endif /* End CY_TCPWM_EchoTimer_H */

/* [] END OF FILE */
