/*******************************************************************************
* File Name: EchoTimer_PM.c
* Version 2.0
*
* Description:
*  This file contains the setup, control, and status commands to support
*  the component operations in the low power mode.
*
* Note:
*  None
*
********************************************************************************
* Copyright 2013-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "EchoTimer.h"

static EchoTimer_BACKUP_STRUCT EchoTimer_backup;


/*******************************************************************************
* Function Name: EchoTimer_SaveConfig
********************************************************************************
*
* Summary:
*  All configuration registers are retention. Nothing to save here.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void EchoTimer_SaveConfig(void)
{

}


/*******************************************************************************
* Function Name: EchoTimer_Sleep
********************************************************************************
*
* Summary:
*  Stops the component operation and saves the user configuration.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void EchoTimer_Sleep(void)
{
    if(0u != (EchoTimer_BLOCK_CONTROL_REG & EchoTimer_MASK))
    {
        EchoTimer_backup.enableState = 1u;
    }
    else
    {
        EchoTimer_backup.enableState = 0u;
    }

    EchoTimer_Stop();
    EchoTimer_SaveConfig();
}


/*******************************************************************************
* Function Name: EchoTimer_RestoreConfig
********************************************************************************
*
* Summary:
*  All configuration registers are retention. Nothing to restore here.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void EchoTimer_RestoreConfig(void)
{

}


/*******************************************************************************
* Function Name: EchoTimer_Wakeup
********************************************************************************
*
* Summary:
*  Restores the user configuration and restores the enable state.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void EchoTimer_Wakeup(void)
{
    EchoTimer_RestoreConfig();

    if(0u != EchoTimer_backup.enableState)
    {
        EchoTimer_Enable();
    }
}


/* [] END OF FILE */
