/*******************************************************************************
* File Name: UltrasoundResponse.c  
* Version 2.10
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "UltrasoundResponse.h"

#define SetP4PinDriveMode(shift, mode)  \
    do { \
        UltrasoundResponse_PC =   (UltrasoundResponse_PC & \
                                (uint32)(~(uint32)(UltrasoundResponse_DRIVE_MODE_IND_MASK << (UltrasoundResponse_DRIVE_MODE_BITS * (shift))))) | \
                                (uint32)((uint32)(mode) << (UltrasoundResponse_DRIVE_MODE_BITS * (shift))); \
    } while (0)


/*******************************************************************************
* Function Name: UltrasoundResponse_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None 
*  
*******************************************************************************/
void UltrasoundResponse_Write(uint8 value) 
{
    uint8 drVal = (uint8)(UltrasoundResponse_DR & (uint8)(~UltrasoundResponse_MASK));
    drVal = (drVal | ((uint8)(value << UltrasoundResponse_SHIFT) & UltrasoundResponse_MASK));
    UltrasoundResponse_DR = (uint32)drVal;
}


/*******************************************************************************
* Function Name: UltrasoundResponse_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  UltrasoundResponse_DM_STRONG     Strong Drive 
*  UltrasoundResponse_DM_OD_HI      Open Drain, Drives High 
*  UltrasoundResponse_DM_OD_LO      Open Drain, Drives Low 
*  UltrasoundResponse_DM_RES_UP     Resistive Pull Up 
*  UltrasoundResponse_DM_RES_DWN    Resistive Pull Down 
*  UltrasoundResponse_DM_RES_UPDWN  Resistive Pull Up/Down 
*  UltrasoundResponse_DM_DIG_HIZ    High Impedance Digital 
*  UltrasoundResponse_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void UltrasoundResponse_SetDriveMode(uint8 mode) 
{
	SetP4PinDriveMode(UltrasoundResponse__0__SHIFT, mode);
}


/*******************************************************************************
* Function Name: UltrasoundResponse_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro UltrasoundResponse_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 UltrasoundResponse_Read(void) 
{
    return (uint8)((UltrasoundResponse_PS & UltrasoundResponse_MASK) >> UltrasoundResponse_SHIFT);
}


/*******************************************************************************
* Function Name: UltrasoundResponse_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 UltrasoundResponse_ReadDataReg(void) 
{
    return (uint8)((UltrasoundResponse_DR & UltrasoundResponse_MASK) >> UltrasoundResponse_SHIFT);
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(UltrasoundResponse_INTSTAT) 

    /*******************************************************************************
    * Function Name: UltrasoundResponse_ClearInterrupt
    ********************************************************************************
    *
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 UltrasoundResponse_ClearInterrupt(void) 
    {
		uint8 maskedStatus = (uint8)(UltrasoundResponse_INTSTAT & UltrasoundResponse_MASK);
		UltrasoundResponse_INTSTAT = maskedStatus;
        return maskedStatus >> UltrasoundResponse_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */
