/*******************************************************************************
* File Name: UltrasoundTrigger.c  
* Version 2.10
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "UltrasoundTrigger.h"

#define SetP4PinDriveMode(shift, mode)  \
    do { \
        UltrasoundTrigger_PC =   (UltrasoundTrigger_PC & \
                                (uint32)(~(uint32)(UltrasoundTrigger_DRIVE_MODE_IND_MASK << (UltrasoundTrigger_DRIVE_MODE_BITS * (shift))))) | \
                                (uint32)((uint32)(mode) << (UltrasoundTrigger_DRIVE_MODE_BITS * (shift))); \
    } while (0)


/*******************************************************************************
* Function Name: UltrasoundTrigger_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None 
*  
*******************************************************************************/
void UltrasoundTrigger_Write(uint8 value) 
{
    uint8 drVal = (uint8)(UltrasoundTrigger_DR & (uint8)(~UltrasoundTrigger_MASK));
    drVal = (drVal | ((uint8)(value << UltrasoundTrigger_SHIFT) & UltrasoundTrigger_MASK));
    UltrasoundTrigger_DR = (uint32)drVal;
}


/*******************************************************************************
* Function Name: UltrasoundTrigger_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  UltrasoundTrigger_DM_STRONG     Strong Drive 
*  UltrasoundTrigger_DM_OD_HI      Open Drain, Drives High 
*  UltrasoundTrigger_DM_OD_LO      Open Drain, Drives Low 
*  UltrasoundTrigger_DM_RES_UP     Resistive Pull Up 
*  UltrasoundTrigger_DM_RES_DWN    Resistive Pull Down 
*  UltrasoundTrigger_DM_RES_UPDWN  Resistive Pull Up/Down 
*  UltrasoundTrigger_DM_DIG_HIZ    High Impedance Digital 
*  UltrasoundTrigger_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void UltrasoundTrigger_SetDriveMode(uint8 mode) 
{
	SetP4PinDriveMode(UltrasoundTrigger__0__SHIFT, mode);
}


/*******************************************************************************
* Function Name: UltrasoundTrigger_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro UltrasoundTrigger_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 UltrasoundTrigger_Read(void) 
{
    return (uint8)((UltrasoundTrigger_PS & UltrasoundTrigger_MASK) >> UltrasoundTrigger_SHIFT);
}


/*******************************************************************************
* Function Name: UltrasoundTrigger_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 UltrasoundTrigger_ReadDataReg(void) 
{
    return (uint8)((UltrasoundTrigger_DR & UltrasoundTrigger_MASK) >> UltrasoundTrigger_SHIFT);
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(UltrasoundTrigger_INTSTAT) 

    /*******************************************************************************
    * Function Name: UltrasoundTrigger_ClearInterrupt
    ********************************************************************************
    *
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 UltrasoundTrigger_ClearInterrupt(void) 
    {
		uint8 maskedStatus = (uint8)(UltrasoundTrigger_INTSTAT & UltrasoundTrigger_MASK);
		UltrasoundTrigger_INTSTAT = maskedStatus;
        return maskedStatus >> UltrasoundTrigger_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */
