/*******************************************************************************
* File Name: UltrasoundTrigger2.c  
* Version 2.10
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "UltrasoundTrigger2.h"

#define SetP4PinDriveMode(shift, mode)  \
    do { \
        UltrasoundTrigger2_PC =   (UltrasoundTrigger2_PC & \
                                (uint32)(~(uint32)(UltrasoundTrigger2_DRIVE_MODE_IND_MASK << (UltrasoundTrigger2_DRIVE_MODE_BITS * (shift))))) | \
                                (uint32)((uint32)(mode) << (UltrasoundTrigger2_DRIVE_MODE_BITS * (shift))); \
    } while (0)


/*******************************************************************************
* Function Name: UltrasoundTrigger2_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None 
*  
*******************************************************************************/
void UltrasoundTrigger2_Write(uint8 value) 
{
    uint8 drVal = (uint8)(UltrasoundTrigger2_DR & (uint8)(~UltrasoundTrigger2_MASK));
    drVal = (drVal | ((uint8)(value << UltrasoundTrigger2_SHIFT) & UltrasoundTrigger2_MASK));
    UltrasoundTrigger2_DR = (uint32)drVal;
}


/*******************************************************************************
* Function Name: UltrasoundTrigger2_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  UltrasoundTrigger2_DM_STRONG     Strong Drive 
*  UltrasoundTrigger2_DM_OD_HI      Open Drain, Drives High 
*  UltrasoundTrigger2_DM_OD_LO      Open Drain, Drives Low 
*  UltrasoundTrigger2_DM_RES_UP     Resistive Pull Up 
*  UltrasoundTrigger2_DM_RES_DWN    Resistive Pull Down 
*  UltrasoundTrigger2_DM_RES_UPDWN  Resistive Pull Up/Down 
*  UltrasoundTrigger2_DM_DIG_HIZ    High Impedance Digital 
*  UltrasoundTrigger2_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void UltrasoundTrigger2_SetDriveMode(uint8 mode) 
{
	SetP4PinDriveMode(UltrasoundTrigger2__0__SHIFT, mode);
}


/*******************************************************************************
* Function Name: UltrasoundTrigger2_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro UltrasoundTrigger2_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 UltrasoundTrigger2_Read(void) 
{
    return (uint8)((UltrasoundTrigger2_PS & UltrasoundTrigger2_MASK) >> UltrasoundTrigger2_SHIFT);
}


/*******************************************************************************
* Function Name: UltrasoundTrigger2_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 UltrasoundTrigger2_ReadDataReg(void) 
{
    return (uint8)((UltrasoundTrigger2_DR & UltrasoundTrigger2_MASK) >> UltrasoundTrigger2_SHIFT);
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(UltrasoundTrigger2_INTSTAT) 

    /*******************************************************************************
    * Function Name: UltrasoundTrigger2_ClearInterrupt
    ********************************************************************************
    *
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 UltrasoundTrigger2_ClearInterrupt(void) 
    {
		uint8 maskedStatus = (uint8)(UltrasoundTrigger2_INTSTAT & UltrasoundTrigger2_MASK);
		UltrasoundTrigger2_INTSTAT = maskedStatus;
        return maskedStatus >> UltrasoundTrigger2_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */
